@@ -13,25 +13,21 @@
 # limitations under the License.
 
 import itertools
-import json
 import os
 from pathlib import Path
 
 import numpy as np
 from scipy import stats
-from sklearn.cluster import KMeans
 
 from asreview.state.utils import states_from_dir, state_from_file
 from asreview.analysis.statistics import _get_labeled_order
 from asreview.analysis.statistics import _get_limits
 from asreview.analysis.statistics import _find_inclusions
 from asreview.analysis.statistics import _get_last_proba_order
-from asreview.analysis.statistics import _random_ttd, _cluster_ttd, _max_ttd
 
 
 class Analysis():
     """Analysis object to do statistical analysis on state files."""
-
     def __init__(self, states, key=None):
         """Class to analyse state files.
 
@@ -72,8 +68,19 @@ class Analysis():
         self.inc_found = {}
 
     @classmethod
-    def from_dir(cls, data_dir, prefix="result", key=None):
-        """Create an Analysis object from a directory."""
+    def from_dir(cls, data_dir, prefix="", key=None):
+        """Create an Analysis object from a directory.
+
+        Arguments
+        ---------
+        data_dir: str
+            Directory to read the state files from.
+        prefix: str
+            Only assume files starting with this prefix are state files.
+            Ignore all other files.
+        key: str
+            Name for the analysis object.
+        """
         if key is None:
             key = os.path.basename(os.path.normpath(data_dir))
         states = states_from_dir(data_dir, prefix=prefix)
@@ -86,7 +93,15 @@ class Analysis():
 
     @classmethod
     def from_file(cls, data_fp, key=None):
-        """Create an Analysis object from a file."""
+        """Create an Analysis object from a file.
+
+        Arguments
+        ---------
+        data_fp: str
+            Path to state file to analyse.
+        key: str
+            Name for analysis object.
+        """
         if key is None:
             key = os.path.basename(os.path.normpath(data_fp))
         state = state_from_file(data_fp)
@@ -98,7 +113,7 @@ class Analysis():
         return analysis_inst
 
     @classmethod
-    def from_path(cls, data_path, prefix="result", key=None):
+    def from_path(cls, data_path, prefix="", key=None):
         """Create an Analysis object from either a file or a directory."""
         if Path(data_path).is_file():
             return cls.from_file(data_path, key=key)
@@ -133,9 +148,7 @@ class Analysis():
         if fl not in self.inc_found:
             # Compute the comclusions if not found in cache.
             self.inc_found[fl] = {}
-            avg, err, iai, ninit = self._get_inc_found(
-                labels=labels, **kwargs
-            )
+            avg, err, iai, ninit = self._get_inc_found(labels=labels, **kwargs)
             self.inc_found[fl]["avg"] = avg
             self.inc_found[fl]["err"] = err
             self.inc_found[fl]["inc_after_init"] = iai
@@ -152,7 +165,8 @@ class Analysis():
             x_norm /= len(labels)
             y_norm /= self.inc_found[fl]["inc_after_init"]
 
-        norm_xr = (np.arange(1, len(self.inc_found[fl]["avg"])+1) - dx) / x_norm
+        norm_xr = (np.arange(1,
+                             len(self.inc_found[fl]["avg"]) + 1) - dx) / x_norm
         norm_yr = (np.array(self.inc_found[fl]["avg"]) - dy) / y_norm
         norm_y_err = np.array(self.inc_found[fl]["err"]) / y_norm
 
@@ -206,15 +220,15 @@ class Analysis():
         tuple:
             Tuple consisting of WSS value, x_positions, y_positions of WSS bar.
         """
-        norm_xr, norm_yr, _ = self.inclusions_found(
-            result_format="percentage", **kwargs)
+        norm_xr, norm_yr, _ = self.inclusions_found(result_format="percentage",
+                                                    **kwargs)
 
         if x_format == "number":
             x_return, y_result, _ = self.inclusions_found(
                 result_format="number", **kwargs)
             y_max = self.inc_found[False]["inc_after_init"]
-            y_coef = y_max / (
-                len(self.labels) - self.inc_found[False]["n_initial"])
+            y_coef = y_max / (len(self.labels) -
+                              self.inc_found[False]["n_initial"])
         else:
             x_return = norm_xr
             y_result = norm_yr
@@ -243,8 +257,8 @@ class Analysis():
             Tuple consisting of RRF value, x_positions, y_positions of RRF bar.
 
         """
-        norm_xr, norm_yr, _ = self.inclusions_found(
-            result_format="percentage", **kwargs)
+        norm_xr, norm_yr, _ = self.inclusions_found(result_format="percentage",
+                                                    **kwargs)
 
         if x_format == "number":
             x_return, y_return, _ = self.inclusions_found(
@@ -260,7 +274,14 @@ class Analysis():
         return (None, None, None)
 
     def avg_time_to_discovery(self, result_format="number"):
-        """Get the best/last estimate on how long it takes to find a paper.
+        """Estimate the Time to Discovery (TD) for each paper.
+
+        Get the best/last estimate on how long it takes to find a paper.
+
+        Arguments
+        ---------
+        result_format: str
+            Desired output format: "number", "fraction" or "percentage".
 
         Returns
         -------
@@ -268,28 +289,38 @@ class Analysis():
             For each inclusion, key=paper_id, value=avg time.
         """
         labels = self.labels
-
         one_labels = np.where(labels == 1)[0]
         time_results = {label: [] for label in one_labels}
 
+        # Iterate over all state files
         for state in self.states.values():
+            # Get the order in which records were labeled
             label_order, n = _get_labeled_order(state)
+            # Get the ranking of all papers at the last query
             proba_order = _get_last_proba_order(state)
+
+            # Adjust factor, depending on the desired output format
             if result_format == "percentage":
-                time_mult = 100 * (len(labels) - n)
+                time_mult = 100 / (len(labels) - n)
+            elif result_format == "fraction":
+                time_mult = 1 / (len(labels) - n)
             else:
                 time_mult = 1
 
+            # Get the time to discovery
             for i_time, idx in enumerate(label_order[n:]):
+                # for all inclusions that were found/labeled
                 if labels[idx] == 1:
-                    time_results[idx].append(time_mult*(i_time+1))
-
+                    time_results[idx].append(time_mult * (i_time + 1))
             for i_time, idx in enumerate(proba_order):
+                # for all inclusions that weren't found/labeled
                 if labels[idx] == 1 and idx not in label_order[:n]:
-                    time_results[idx].append(
-                        time_mult*(i_time + len(label_order)))
+                    time_results[idx].append(time_mult *
+                                             (i_time + len(label_order) + 1))
 
         results = {}
+
+        # Merge the results of all state files
         for label, trained_time in time_results.items():
             if len(trained_time) > 0:
                 results[label] = np.average(trained_time)
@@ -330,11 +361,10 @@ class Analysis():
         n_train = 0
         _, n_initial = _get_labeled_order(state)
         for query_i in range(n_queries):
-            new_limits = _get_limits(
-                self.states,
-                query_i,
-                self.labels,
-                proba_allow_miss=prob_allow_miss)
+            new_limits = _get_limits(self.states,
+                                     query_i,
+                                     self.labels,
+                                     proba_allow_miss=prob_allow_miss)
 
             try:
                 new_train_idx = state.get("train_idx", query_i)
@@ -365,46 +395,6 @@ class Analysis():
                                                  res_dtype)
         return results
 
-    def time_to_inclusion(self, X_fp):
-        with open(X_fp, "r") as fp:
-            X = np.array(json.load(fp))
-
-        n_clusters = int(len(self.labels) / 150)
-        model = KMeans(n_clusters=n_clusters, n_init=1)
-        clusters = model.fit_predict(X, self.labels)
-        state = self.states[self._first_file]
-        n_queries = state.n_queries()
-
-        results = {
-            "x_range": [],
-            "ttd": {
-                "random": [],
-                "cluster": [],
-                "max": [],
-            }
-        }
-        n_train = 0
-        for query_i in range(n_queries):
-            new_random_ttd = _random_ttd(self.states, query_i, self.labels)
-            new_cluster_ttd = _cluster_ttd(self.states, query_i, self.labels,
-                                           clusters)
-            new_max_ttd = _max_ttd(self.states, query_i, self.labels)
-
-            results["ttd"]["random"].append(new_random_ttd)
-            results["ttd"]["cluster"].append(new_cluster_ttd)
-            results["ttd"]["max"].append(new_max_ttd)
-
-            try:
-                new_train_idx = state.get("train_idx", query_i)
-            except KeyError:
-                new_train_idx = None
-
-            if new_train_idx is not None:
-                n_train = len(new_train_idx)
-            results["x_range"].append(n_train)
-
-        return results
-
     def close(self):
         """Close states."""
         for state in self.states.values():
