@@ -22,7 +22,7 @@ from asreview.utils import get_random_state
 
 
 class DoubleBalance(BaseBalance):
-    """Class for the double balance strategy.
+    """Dynamic Resampling balance strategy.
 
     Class to get the two way rebalancing function and arguments.
     It super samples ones depending on the number of 0's and total number
@@ -50,9 +50,12 @@ class DoubleBalance(BaseBalance):
 
     name = "double"
 
-    def __init__(self, a=2.155, alpha=0.94, b=0.789, beta=1.0,
+    def __init__(self,
+                 a=2.155,
+                 alpha=0.94,
+                 b=0.789,
+                 beta=1.0,
                  random_state=None):
-
         super(DoubleBalance, self).__init__()
         self.a = a
         self.alpha = alpha
@@ -62,10 +65,29 @@ class DoubleBalance(BaseBalance):
         self._random_state = get_random_state(random_state)
 
     def sample(self, X, y, train_idx, shared):
+        """Resample the training data.
+
+        Arguments
+        ---------
+        X: np.array
+            Complete feature matrix.
+        y: np.array
+            Labels for all papers.
+        train_idx: np.array
+            Training indices, that is all papers that have been reviewed.
+        shared: dict
+            Dictionary to share data between balancing models and other models.
+
+        Returns
+        -------
+        np.array, np.array:
+            X_train, y_train: the resampled matrix, labels.
+        """
+        # Get inclusions and exclusions
         one_idx = train_idx[np.where(y[train_idx] == 1)]
         zero_idx = train_idx[np.where(y[train_idx] == 0)]
 
-        # Fall back to simple sampling if we have only ones or zeros.
+        # Fall back to simple sampling if we have only ones or zeroes.
         if len(one_idx) == 0 or len(zero_idx) == 0:
             self.fallback_model.sample(X, y, train_idx, shared)
 
@@ -73,23 +95,27 @@ class DoubleBalance(BaseBalance):
         n_zero = len(zero_idx)
         n_train = n_one + n_zero
 
-        # Compute the weights.
+        # Compute sampling weights.
         one_weight = _one_weight(n_one, n_zero, self.a, self.alpha)
         zero_weight = _zero_weight(n_one + n_zero, self.b, self.beta)
         tot_zo_weight = one_weight * n_one + zero_weight * n_zero
+        # Number of inclusions to sample.
         n_one_train = random_round(
             one_weight * n_one * n_train / tot_zo_weight, self._random_state)
+        # Should be at least 1, and at least two spots should be for exclusions.
         n_one_train = max(1, min(n_train - 2, n_one_train))
+        # Number of exclusions to sample
         n_zero_train = n_train - n_one_train
 
-        # Get random ones and zeros.
+        # Sample records of ones and zeroes
         one_train_idx = fill_training(one_idx, n_one_train, self._random_state)
         zero_train_idx = fill_training(zero_idx, n_zero_train,
                                        self._random_state)
-
+        # Merge and shuffle.
         all_idx = np.concatenate([one_train_idx, zero_train_idx])
         self._random_state.shuffle(all_idx)
 
+        # Return resampled feature matrix and labels.
         return X[all_idx], y[all_idx]
 
     def full_hyper_space(self):
@@ -128,14 +154,16 @@ def random_round(value, random_state):
 
 
 def fill_training(src_idx, n_train, random_state):
-    """Copy/sample until there are n_train indices sampled.
+    """Copy/sample until there are n_train indices sampled/copied.
     """
-    # Copy as many as we need, rounded down.
+    # Number of copies needed.
     n_copy = np.int(n_train / len(src_idx))
+    # For the remainder, use sampling.
     n_sample = n_train - n_copy * len(src_idx)
-    dest_idx = np.tile(src_idx, n_copy).reshape(-1)
 
-    # Add samples to finish up.
+    # Copy indices
+    dest_idx = np.tile(src_idx, n_copy).reshape(-1)
+    # Add samples
     dest_idx = np.append(dest_idx,
                          random_state.choice(src_idx, n_sample, replace=False))
     return dest_idx
