@@ -1,5 +1,7 @@
 import os
 
+import pandas as pd
+
 from asreview.config import LABEL_NA
 from asreview.utils import format_to_str
 
@@ -27,8 +29,9 @@ class PaperRecord():
     """
     def __init__(self, record_id, column_spec={}, **kwargs):
 
-        for attr in ["title", "abstract", "authors", "keywords",
-                     "final_included"]:
+        for attr in [
+                "title", "abstract", "authors", "keywords", "final_included"
+        ]:
             if attr in column_spec:
                 col = column_spec[attr]
             elif attr in kwargs:
@@ -45,6 +48,10 @@ class PaperRecord():
 
         self.extra_fields = kwargs
 
+        for attr, val in self.extra_fields.items():
+            if pd.isna(val):
+                self.extra_fields[attr] = None
+
     def preview(self, w_title=80, w_authors=40, automatic_width=False):
         """Return a single line preview string for record i.
 
@@ -64,8 +71,8 @@ class PaperRecord():
         """
         if automatic_width:
             term_width = os.get_terminal_size().columns
-            width_available = term_width-7
-            w_title = round((2/3)*width_available)
+            width_available = term_width - 7
+            w_title = round((2 / 3) * width_available)
             w_authors = width_available - w_title
         title_str = ""
         author_str = ""
