@@ -3,10 +3,10 @@ import logging
 import pandas as pd
 from RISparser import readris
 from RISparser import TAG_KEY_MAPPING
+from RISparser.config import LIST_TYPE_TAGS
 
 from asreview.config import COLUMN_DEFINITIONS
-from asreview.io.utils import standardize_dataframe, convert_keywords
-from RISparser.config import LIST_TYPE_TAGS
+from asreview.io.utils import standardize_dataframe
 
 
 RIS_KEY_LABEL_INCLUDED = "LI"
@@ -51,8 +51,10 @@ def read_ris(fp):
                 mapping = _tag_key_mapping(reverse=False)
                 entries = list(readris(bibliography_file, mapping=mapping))
                 break
-        except (UnicodeDecodeError, IOError):
+        except UnicodeDecodeError:
             pass
+        except IOError as e:
+            logging.warning(e)
 
     if entries is None:
         raise ValueError("Cannot find proper encoding for data file.")
