@@ -12,7 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from asreview.utils import model_class_from_entry_point
+from asreview.utils import list_model_names
+from asreview.utils import _model_class_from_entry_point
+
+
+def list_classifiers():
+    """List available classifiers.
+
+    Returns
+    -------
+    list:
+        Names of available classifiers in alphabetical order.
+    """
+    return list_model_names(entry_name="asreview.models")
 
 
 def get_model_class(method):
@@ -28,7 +40,7 @@ def get_model_class(method):
     BaseModel:
         Class corresponding to the method.
     """
-    return model_class_from_entry_point(method, "asreview.models")
+    return _model_class_from_entry_point(method, "asreview.models")
 
 
 def get_model(method, *args, random_state=None, **kwargs):
