@@ -18,22 +18,40 @@ import warnings
 
 import numpy as np
 
+from asreview.balance_strategies.simple import SimpleBalance
 from asreview.config import DEFAULT_N_INSTANCES, LABEL_NA
-from asreview.state.utils import open_state
+from asreview.feature_extraction.tfidf import Tfidf
 from asreview.models.nb import NBModel
 from asreview.query_strategies.max import MaxQuery
-from asreview.balance_strategies.simple import SimpleBalance
 from asreview.query_strategies.random import RandomQuery
 from asreview.settings import ASReviewSettings
-from asreview.feature_extraction.tfidf import Tfidf
+from asreview.state.utils import open_state
 
 
 def get_pool_idx(X, train_idx):
+    "Return pool indices from training indices."
     return np.delete(np.arange(X.shape[0]), train_idx, axis=0)
 
 
 def _merge_prior_knowledge(included, excluded, return_labels=True):
-    """Merge prior included and prior excluded."""
+    """Merge prior included and prior excluded.
+
+    Parameters
+    ----------
+    included: numpy.array
+        Array of indices which should be included.
+    excluded: numpy.array
+        Array of indices which should be excluded.
+    return_labels: bool
+        Return the labels of the merged priors.
+
+    Returns
+    -------
+    numpy.array:
+        Merged prior inclusions + exclusions.
+    numpy.array:
+        (Optional) labels of the merged priors.
+    """
 
     if included is None:
         included = []
@@ -43,78 +61,68 @@ def _merge_prior_knowledge(included, excluded, return_labels=True):
     prior_indices = np.array(np.append(included, excluded), dtype=np.int)
 
     if return_labels:
-        prior_included_labels = np.ones((len(included),), dtype=int)
-        prior_excluded_labels = np.zeros((len(excluded),), dtype=int)
+        prior_included_labels = np.ones((len(included), ), dtype=int)
+        prior_excluded_labels = np.zeros((len(excluded), ), dtype=int)
 
-        labels = np.concatenate([
-            prior_included_labels,
-            prior_excluded_labels
-        ])
+        labels = np.concatenate([prior_included_labels, prior_excluded_labels])
         return prior_indices, labels
     return prior_indices
 
 
 class BaseReview(ABC):
-    """Base class for Systematic Review"""
+    """Base class for Systematic Review.
+
+    Arguments
+    ---------
+    as_data: asreview.ASReviewData
+        The data object which contains the text, labels, etc.
+    model: BaseModel
+        Initialized model to fit the data during active learning.
+        See asreview.models.utils.py for possible models.
+    query_model: BaseQueryModel
+        Initialized model to query new instances for review, such as random
+        sampling or max sampling.
+        See asreview.query_strategies.utils.py for query models.
+    balance_model: BaseBalanceModel
+        Initialized model to redistribute the training data during the
+        active learning process. They might either resample or undersample
+        specific papers.
+    feature_model: BaseFeatureModel
+        Feature extraction model that converts texts and keywords to
+        feature matrices.
+    n_papers: int
+        Number of papers to review during the active learning process,
+        excluding the number of initial priors. To review all papers, set
+        n_papers to None.
+    n_instances: int
+        Number of papers to query at each step in the active learning
+        process.
+    n_queries: int
+        Number of steps/queries to perform. Set to None for no limit.
+    start_idx: numpy.array
+        Start the simulation/review with these indices. They are assumed to
+        be already labeled. Failing to do so might result bad behaviour.
+    state_file: str
+        Path to state file. Replaces log_file argument.
+    """
+
     name = "base"
 
-    def __init__(self,
-                 as_data,
-                 model=None,
-                 query_model=None,
-                 balance_model=None,
-                 feature_model=None,
-                 n_papers=None,
-                 n_instances=DEFAULT_N_INSTANCES,
-                 n_queries=None,
-                 start_idx=[],
-                 state_file=None,
-                 log_file=None,
-#                  final_labels=None,
-                 verbose=1,
-                 data_fp=None,
-                 ):
-        """ Initialize base class for systematic reviews.
-
-        Arguments
-        ---------
-        X: np.array
-            The feature matrix for the current dataset.
-        y: np.array
-            Labels of each paper, 1 for included, 0 for excluded.
-            Can be set to None, to indicate inclusion data is not available.
-        model: BaseModel
-            Initialized model to fit the data during active learning.
-            See asreview.models.utils.py for possible models.
-        query_model: BaseQueryModel
-            Initialized model to query new instances for review, such as random
-            sampling or max sampling.
-            See asreview.query_strategies.utils.py for query models.
-        balance_model: BaseBalanceModel
-            Initialized model to redistribute the training data during the
-            active learning process. They might either resample or undersample
-            specific papers.
-        n_papers: int
-            Number of papers to review during the active learning process,
-            excluding the number of initial priors. To review all papers, set
-            n_papers to None.
-        n_instances: int
-            Number of papers to query at each step in the active learning
-            process.
-        n_queries: int
-            Number of steps/queries to perform. Set to None for no limit.
-        prior_included: list
-            List of papers (ids) that are included a priori.
-        prior_excluded: list
-            List of papers (ids) that are excluded a priori.
-        state_file: str
-            Path to state file. Replaces log_file argument.
-        final_labels: np.array
-            Final labels if we're using a two step inclusion process.
-            For example, if at one step a paper is considered after reading the
-            abstract and then at the second step, a final decision is made on
-            the basis of the full text.
-        """
+    def __init__(
+        self,
+        as_data,
+        model=None,
+        query_model=None,
+        balance_model=None,
+        feature_model=None,
+        n_papers=None,
+        n_instances=DEFAULT_N_INSTANCES,
+        n_queries=None,
+        start_idx=[],
+        state_file=None,
+        log_file=None,
+    ):
+        """Initialize base class for systematic reviews."""
         super(BaseReview, self).__init__()
 
         # Default to Naive Bayes model
@@ -147,25 +155,30 @@ class BaseReview(ABC):
         self.start_idx = start_idx
 
         if log_file is not None:
-            warnings.warn("The log_file argument for BaseReview will be"
-                          " replaced by state_file.", category=FutureWarning)
+            warnings.warn(
+                "The log_file argument for BaseReview will be"
+                " replaced by state_file.",
+                category=FutureWarning)
             self.state_file = log_file
         else:
             self.state_file = state_file
-        self.verbose = verbose
 
         self.query_i = 0
         self.query_i_classified = 0
         self.train_idx = np.array([], dtype=np.int)
         self.model_trained = False
-        self.data_fp = data_fp
 
+        # Restore the state from a file or initialize said file.
         with open_state(self.state_file) as state:
+            # From file
             if not state.is_empty():
                 startup = state.startup_vals()
+                # If there are start indices not in the training add them.
                 if not set(startup["train_idx"]) >= set(start_idx):
-                    new_idx = list(set(start_idx)-set(startup["train_idx"]))
-                    self.classify(new_idx, self.y[new_idx], state,
+                    new_idx = list(set(start_idx) - set(startup["train_idx"]))
+                    self.classify(new_idx,
+                                  self.y[new_idx],
+                                  state,
                                   method="initial")
                     startup = state.startup_vals()
                 self.train_idx = startup["train_idx"]
@@ -173,19 +186,24 @@ class BaseReview(ABC):
                 self.shared["query_src"] = startup["query_src"]
                 self.query_i = startup["query_i"]
                 self.query_i_classified = startup["query_i_classified"]
+            # From scratch
             else:
                 state.set_labels(self.y)
                 state.settings = self.settings
-                self.classify(start_idx, self.y[start_idx], state,
+                self.classify(start_idx,
+                              self.y[start_idx],
+                              state,
                               method="initial")
                 self.query_i_classified = len(start_idx)
 
+            # Try to retrieve feature matrix from the state file.
             try:
                 self.X = state.get_feature_matrix(as_data.hash())
             except KeyError:
-                self.X = feature_model.fit_transform(
-                    as_data.texts, as_data.headings, as_data.bodies,
-                    as_data.keywords)
+                self.X = feature_model.fit_transform(as_data.texts,
+                                                     as_data.headings,
+                                                     as_data.bodies,
+                                                     as_data.keywords)
                 state._add_as_data(as_data, feature_matrix=self.X)
             if self.X.shape[0] != len(self.y):
                 raise ValueError("The state file does not correspond to the "
@@ -195,25 +213,26 @@ class BaseReview(ABC):
 
     @property
     def settings(self):
+        """Get an ASReview settings object"""
         extra_kwargs = {}
         if hasattr(self, 'n_prior_included'):
             extra_kwargs['n_prior_included'] = self.n_prior_included
         if hasattr(self, 'n_prior_excluded'):
             extra_kwargs['n_prior_excluded'] = self.n_prior_excluded
-        return ASReviewSettings(
-            mode=self.name, model=self.model.name,
-            query_strategy=self.query_model.name,
-            balance_strategy=self.balance_model.name,
-            feature_extraction=self.feature_model.name,
-            n_instances=self.n_instances,
-            n_queries=self.n_queries,
-            n_papers=self.n_papers,
-            model_param=self.model.param,
-            query_param=self.query_model.param,
-            balance_param=self.balance_model.param,
-            feature_param=self.feature_model.param,
-            data_name=self.as_data.data_name,
-            **extra_kwargs)
+        return ASReviewSettings(mode=self.name,
+                                model=self.model.name,
+                                query_strategy=self.query_model.name,
+                                balance_strategy=self.balance_model.name,
+                                feature_extraction=self.feature_model.name,
+                                n_instances=self.n_instances,
+                                n_queries=self.n_queries,
+                                n_papers=self.n_papers,
+                                model_param=self.model.param,
+                                query_param=self.query_model.param,
+                                balance_param=self.balance_model.param,
+                                feature_param=self.feature_model.param,
+                                data_name=self.as_data.data_name,
+                                **extra_kwargs)
 
     @abstractmethod
     def _get_labels(self, ind):
@@ -246,6 +265,13 @@ class BaseReview(ABC):
         return stop_iter
 
     def n_pool(self):
+        """Number of indices left in the pool.
+
+        Returns
+        -------
+        int:
+            Number of indices left in the pool.
+        """
         return self.X.shape[0] - len(self.train_idx)
 
     def _next_n_instances(self):  # Could be merged with _stop_iter someday.
@@ -269,11 +295,9 @@ class BaseReview(ABC):
 
         n_pool = self.X.shape[0] - len(self.train_idx)
 
-        while not self._stop_iter(self.query_i-1, n_pool):
+        while not self._stop_iter(self.query_i - 1, n_pool):
             # STEP 1: Make a new query
-            query_idx = self.query(
-                n_instances=self._next_n_instances()
-            )
+            query_idx = self.query(n_instances=self._next_n_instances())
             self.log_current_query(state)
 
             # STEP 2: Classify the queried papers.
@@ -338,12 +362,12 @@ class BaseReview(ABC):
             self.shared["current_queries"] = {}
 
     def query(self, n_instances, query_model=None):
-        """Query new results.
+        """Query records from pool.
 
         Arguments
         ---------
         n_instances: int
-            Batch size of the queries, i.e. number of papers to be queried.
+            Batch size of the queries, i.e. number of records to be queried.
         query_model: BaseQueryModel
             Query strategy model to use. If None, the query model of the
             reviewer is used.
@@ -351,7 +375,7 @@ class BaseReview(ABC):
         Returns
         -------
         np.array:
-            Indices of papers queried.
+            Indices of records queried.
         """
 
         pool_idx = get_pool_idx(self.X, self.train_idx)
@@ -379,7 +403,7 @@ class BaseReview(ABC):
         return query_idx
 
     def classify(self, query_idx, inclusions, state, method=None):
-        """ Classify new papers and update the training indices.
+        """Classify new papers and update the training indices.
 
         It automaticaly updates the state.
 
@@ -391,12 +415,15 @@ class BaseReview(ABC):
             Labels of the query_idx.
         state: BaseLogger
             Logger to store the classification in.
+        method: str
+            If not set to None, all inclusions have this query method.
         """
         query_idx = np.array(query_idx, dtype=np.int)
         self.y[query_idx] = inclusions
         query_idx = query_idx[np.isin(query_idx, self.train_idx, invert=True)]
         self.train_idx = np.append(self.train_idx, query_idx)
         if method is None:
+            # Find query method in current queries.
             methods = []
             for idx in query_idx:
                 method = self.shared["current_queries"].pop(idx, None)
@@ -410,12 +437,13 @@ class BaseReview(ABC):
         else:
             methods = np.full(len(query_idx), method)
             if method in self.shared["query_src"]:
-                self.shared["query_src"][method].extend(
-                    query_idx.tolist())
+                self.shared["query_src"][method].extend(query_idx.tolist())
             else:
                 self.shared["query_src"][method] = query_idx.tolist()
 
-        state.add_classification(query_idx, inclusions, methods=methods,
+        state.add_classification(query_idx,
+                                 inclusions,
+                                 methods=methods,
                                  query_i=self.query_i)
         state.set_labels(self.y)
 
@@ -428,8 +456,10 @@ class BaseReview(ABC):
             return
 
         # Get the training data.
-        X_train, y_train = self.balance_model.sample(
-            self.X, self.y, self.train_idx, shared=self.shared)
+        X_train, y_train = self.balance_model.sample(self.X,
+                                                     self.y,
+                                                     self.train_idx,
+                                                     shared=self.shared)
 
         # Train the model on the training data.
         self.model.fit(
@@ -443,7 +473,14 @@ class BaseReview(ABC):
             self.query_i_classified = 0
 
     def statistics(self):
-        "Get a number of statistics about the current state of the review."
+        """Get statistics on the current state of the review.
+
+        Returns
+        -------
+        dict:
+            A dictonary with statistics like n_included and
+            last_inclusion.
+        """
         try:
             n_initial = len(self.shared['query_src']['initial'])
         except KeyError:
@@ -468,37 +505,3 @@ class BaseReview(ABC):
             "n_initial": n_initial,
         }
         return stats
-
-#     def save(self, pickle_fp):
-#         """Dump the self object to a pickle fill (using dill).
-# 
-#         Keras models cannot be dumped, so they are written to a separate
-#         h5 file. The model is briefly popped out of the object to allow the
-#         rest to be written to a file. Do not rely on this method for long term
-#         storage of the class, since library changes could easily break it.
-#         In those cases, use the state + h5 file instead.
-#         """
-#         if isinstance(self.model, KerasClassifier) and self.model_trained:
-#             model_fp = os.path.splitext(pickle_fp)[0]+".h5"
-#             self.model.model.save(model_fp)
-#             current_model = self.model.__dict__.pop("model", None)
-#             with open(pickle_fp, "wb") as fp:
-#                 dill.dump(self, fp)
-#             setattr(self.model, "model", current_model)
-#         else:
-#             dill.dump(self, fp)
-# 
-#     @classmethod
-#     def load(cls, pickle_fp):
-#         """
-#         Create a BaseReview object from a pickle file.
-#         """
-#         with open(pickle_fp, "rb") as fp:
-#             my_instance = dill.load(fp)
-#         try:
-#             model_fp = os.path.splitext(pickle_fp)[0]+".h5"
-#             current_model = load_model(model_fp)
-#             setattr(my_instance.model, "model", current_model)
-#         except Exception:
-#             pass
-#         return my_instance
