@@ -45,6 +45,7 @@ SETTINGS_TYPE_DICT = {
 
 
 def _convert_types(par_defaults, param):
+    """Convert strings from the config file to the appropriate type."""
     for par in param:
         try:
             par_type = type(par_defaults[par])
@@ -125,8 +126,8 @@ class ASReviewSettings(object):
                           "feature_param"]:
                 setattr(self, sect, dict(config.items(sect)))
             elif sect != "DEFAULT":
-                print (f"Warning: section [{sect}] is ignored in "
-                       f"config file {config_file}")
+                print(f"Warning: section [{sect}] is ignored in "
+                      f"config file {config_file}")
 
         model = get_model(self.model)
         _convert_types(model.default_param, self.model_param)
@@ -137,10 +138,13 @@ class ASReviewSettings(object):
         feature_model = get_feature_model(self.feature_extraction)
         _convert_types(feature_model.default_param, self.feature_param)
 
-    def __str__(self):
+    def to_dict(self):
         info_dict = {}
         for attrib in SETTINGS_TYPE_DICT:
             value = getattr(self, attrib, None)
             if value is not None:
-                info_dict[attrib] = str(value)
-        return pretty_format(info_dict)
+                info_dict[attrib] = value
+        return info_dict
+
+    def __str__(self):
+        return pretty_format(self.to_dict())
