@@ -175,7 +175,12 @@ def is_iterable(i):
         return False
 
 
-def model_class_from_entry_point(method, entry_name="asreview.models"):
+def list_model_names(entry_name="asreview.models"):
+    return [entry.name
+            for entry in pkg_resources.iter_entry_points(entry_name)]
+
+
+def _model_class_from_entry_point(method, entry_name="asreview.models"):
     entry_points = {
         entry.name: entry
         for entry in pkg_resources.iter_entry_points(entry_name)
@@ -193,15 +198,25 @@ def model_class_from_entry_point(method, entry_name="asreview.models"):
 
 
 def is_url(url):
+    """Check if object is a valid url."""
     try:
         result = urlparse(url)
         return all(getattr(result, x) != ""
                    for x in ["scheme", "netloc", "path"])
-    except:
+    except Exception:
         return False
 
 
 def get_random_state(random_state):
+    """Create a RandomState instance.
+
+    Parameters
+    ----------
+    random_state: int, numpy.RandomState
+        If it is an integer, seed a new random state.
+        If it is a RandomState, return it (nop).
+        If it is None, return the random state of numpy.
+    """
     if random_state is None:
         return np.random.random.__self__
     else:
@@ -210,4 +225,3 @@ def get_random_state(random_state):
         else:
             return np.random.RandomState(
                 random_state % (2**32))
-
